==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRequestMirrorFilterFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRequestMirrorFilterFluentImpl<A extends HTTPRequestMirrorFilterFluent<A>> extends BaseFluent<A> implements HTTPRequestMirrorFilterFluent<A>{
  public HTTPRequestMirrorFilterFluentImpl() {
  }
  public HTTPRequestMirrorFilterFluentImpl(HTTPRequestMirrorFilter instance) {
    this.withBackendRef(instance.getBackendRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private BackendObjectReferenceBuilder backendRef;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildBackendRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public BackendObjectReference getBackendRef() {
    return this.backendRef!=null ?this.backendRef.build():null;
  }
  public BackendObjectReference buildBackendRef() {
    return this.backendRef!=null ?this.backendRef.build():null;
  }
  public A withBackendRef(BackendObjectReference backendRef) {
    _visitables.get("backendRef").remove(this.backendRef);
    if (backendRef!=null){ this.backendRef= new BackendObjectReferenceBuilder(backendRef); _visitables.get("backendRef").add(this.backendRef);} else { this.backendRef = null; _visitables.get("backendRef").remove(this.backendRef); } return (A) this;
  }
  public Boolean hasBackendRef() {
    return this.backendRef != null;
  }
  public A withNewBackendRef(String group,String kind,String name,String namespace,Integer port) {
    return (A)withBackendRef(new BackendObjectReference(group, kind, name, namespace, port));
  }
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> withNewBackendRef() {
    return new HTTPRequestMirrorFilterFluentImpl.BackendRefNestedImpl();
  }
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> withNewBackendRefLike(BackendObjectReference item) {
    return new HTTPRequestMirrorFilterFluentImpl.BackendRefNestedImpl(item);
  }
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editBackendRef() {
    return withNewBackendRefLike(getBackendRef());
  }
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editOrNewBackendRef() {
    return withNewBackendRefLike(getBackendRef() != null ? getBackendRef(): new BackendObjectReferenceBuilder().build());
  }
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editOrNewBackendRefLike(BackendObjectReference item) {
    return withNewBackendRefLike(getBackendRef() != null ? getBackendRef(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPRequestMirrorFilterFluentImpl that = (HTTPRequestMirrorFilterFluentImpl) o;
    if (backendRef != null ? !backendRef.equals(that.backendRef) :that.backendRef != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backendRef,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (backendRef != null) { sb.append("backendRef:"); sb.append(backendRef + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class BackendRefNestedImpl<N> extends BackendObjectReferenceFluentImpl<HTTPRequestMirrorFilterFluent.BackendRefNested<N>> implements HTTPRequestMirrorFilterFluent.BackendRefNested<N>,Nested<N>{
    BackendRefNestedImpl(BackendObjectReference item) {
      this.builder = new BackendObjectReferenceBuilder(this, item);
    }
    BackendRefNestedImpl() {
      this.builder = new BackendObjectReferenceBuilder(this);
    }
    BackendObjectReferenceBuilder builder;
    public N and() {
      return (N) HTTPRequestMirrorFilterFluentImpl.this.withBackendRef(builder.build());
    }
    public N endBackendRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRequestMirrorFilterFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRequestMirrorFilterFluentImpl<A extends HTTPRequestMirrorFilterFluent<A>> extends BaseFluent<A> implements HTTPRequestMirrorFilterFluent<A>{
  public HTTPRequestMirrorFilterFluentImpl() {
  }
  public HTTPRequestMirrorFilterFluentImpl(HTTPRequestMirrorFilter instance) {
    if (instance != null) {
      this.withBackendRef(instance.getBackendRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private BackendObjectReferenceBuilder backendRef;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildBackendRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public BackendObjectReference getBackendRef() {
    return this.backendRef!=null ?this.backendRef.build():null;
  }
  public BackendObjectReference buildBackendRef() {
    return this.backendRef!=null ?this.backendRef.build():null;
  }
  public A withBackendRef(BackendObjectReference backendRef) {
    _visitables.get("backendRef").remove(this.backendRef);
    if (backendRef!=null){ this.backendRef= new BackendObjectReferenceBuilder(backendRef); _visitables.get("backendRef").add(this.backendRef);} else { this.backendRef = null; _visitables.get("backendRef").remove(this.backendRef); } return (A) this;
  }
  public Boolean hasBackendRef() {
    return this.backendRef != null;
  }
  public A withNewBackendRef(String group,String kind,String name,String namespace,Integer port) {
    return (A)withBackendRef(new BackendObjectReference(group, kind, name, namespace, port));
  }
  public HTTPRequestMirrorFilterFluentImpl.BackendRefNested<A> withNewBackendRef() {
    return new HTTPRequestMirrorFilterFluentImpl.BackendRefNestedImpl();
  }
  public HTTPRequestMirrorFilterFluentImpl.BackendRefNested<A> withNewBackendRefLike(BackendObjectReference item) {
    return new HTTPRequestMirrorFilterFluentImpl.BackendRefNestedImpl(item);
  }
  public HTTPRequestMirrorFilterFluentImpl.BackendRefNested<A> editBackendRef() {
    return withNewBackendRefLike(getBackendRef());
  }
  public HTTPRequestMirrorFilterFluentImpl.BackendRefNested<A> editOrNewBackendRef() {
    return withNewBackendRefLike(getBackendRef() != null ? getBackendRef(): new BackendObjectReferenceBuilder().build());
  }
  public HTTPRequestMirrorFilterFluentImpl.BackendRefNested<A> editOrNewBackendRefLike(BackendObjectReference item) {
    return withNewBackendRefLike(getBackendRef() != null ? getBackendRef(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRequestMirrorFilterFluentImpl that = (HTTPRequestMirrorFilterFluentImpl) o;
    if (!java.util.Objects.equals(backendRef, that.backendRef)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backendRef,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (backendRef != null) { sb.append("backendRef:"); sb.append(backendRef + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class BackendRefNestedImpl<N> extends BackendObjectReferenceFluentImpl<HTTPRequestMirrorFilterFluentImpl.BackendRefNested<N>> implements HTTPRequestMirrorFilterFluentImpl.BackendRefNested<N>,Nested<N>{
    BackendRefNestedImpl(BackendObjectReference item) {
      this.builder = new BackendObjectReferenceBuilder(this, item);
    }
    BackendRefNestedImpl() {
      this.builder = new BackendObjectReferenceBuilder(this);
    }
    BackendObjectReferenceBuilder builder;
    public N and() {
      return (N) HTTPRequestMirrorFilterFluentImpl.this.withBackendRef(builder.build());
    }
    public N endBackendRef() {
      return and();
    }
    
  }
  
}
